@@ -1,9 +1,10 @@
 import dataclasses
+import typing
 
 from demapi.connector.file import File
 
 
 @dataclasses.dataclass
 class RequestPayload:
-    data: dict
+    data: typing.Dict[str, typing.Any]
     file: File
