@@ -9,19 +9,18 @@ import requests
 
 from demapi.connector.file import File
 
-BaseSyncConnectorType = typing.TypeVar("BaseSyncConnectorType")
-
 
 class BaseSyncConnector(abc.ABC):
     @classmethod
+    @contextlib.contextmanager
     @abc.abstractmethod
-    def new(
-        cls: typing.Type[BaseSyncConnectorType],
-    ) -> typing.ContextManager[BaseSyncConnectorType]:
+    def new(cls) -> typing.Iterator[BaseSyncConnector]:
         pass  # pragma: no cover
 
     @abc.abstractmethod
-    def post(self, url: str, data: dict, file: File) -> bytes:
+    def post(
+        self, url: str, data: typing.Dict[str, typing.Any], file: File
+    ) -> bytes:
         pass  # pragma: no cover
 
     @abc.abstractmethod
@@ -35,13 +34,15 @@ class RequestsConnector(BaseSyncConnector):
 
     @classmethod
     @contextlib.contextmanager
-    def new(cls) -> RequestsConnector:
+    def new(cls) -> typing.Iterator[RequestsConnector]:
         session = requests.Session()
         self = cls(session=session)
         with session:
             yield self
 
-    def post(self, url: str, data: dict, file: File) -> bytes:
+    def post(
+        self, url: str, data: typing.Dict[str, typing.Any], file: File
+    ) -> bytes:
         file_obj = {file.multipart_name: (file.name, file.content)}
         return self.session.post(
             url,
